@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use v5.10;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 # ABSTRACT: A helper class for C<JIRA::REST::Class> that represents a JIRA project as an object.
 
 __PACKAGE__->mk_data_ro_accessors(qw( avatarUrls expand id key name projectTypeKey self ));
 
 _make_lazy_ro_accessors(qw/ category assigneeType components description
-                            issueTypes lead roles versions /);
+                            issueTypes subtaskIssueTypes lead roles versions /);
 
 use overload
     '""'   => sub { shift->key },
@@ -57,6 +57,10 @@ sub _do_lazy_load {
         $self->make_object('issuetype', { data => $_ });
     } @{ $data->{issueTypes} } ];
 
+    $self->{subtaskIssueTypes} = [ grep {
+        $_->subtask
+    } @{ $self->{issueTypes} } ];
+
     $self->{lead} = $self->make_object('user', { data => $data->{lead} });
 
     $self->{roles} = $data->{roles};
@@ -157,7 +161,6 @@ sub field_name {
     return $self->{field_names}->{$name};
 }
 
-
 1;
 
 __END__
@@ -172,47 +175,64 @@ JIRA::REST::Class::Project - A helper class for C<JIRA::REST::Class> that repres
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 METHODS
 
 =head2 B<assigneeType>
+
 This method returns the assignee type of the project.
 
 =head2 B<avatarUrls>
+
 A hashref of the different sizes available for the project's avatar.
 
 =head2 B<components>
+
 A list of the components for the project.
 
 =head2 B<description>
+
 Returns the description of the project.
 
 =head2 B<expand>
+
 Heck if I know what this field does.
 
 =head2 B<id>
+
 Returns the id of the project.
 
 =head2 B<issueTypes>
+
 A list of valid issue types for the project.
 
+=head2 B<subtaskIssueTypes>
+
+Taking a page from the old SOAP interface, this method returns a list of all issue types whose subtask field is true.
+
 =head2 B<key>
+
 Returns the key of the project.
 
 =head2 B<lead>
+
 Returns the project lead as a C<JIRA::REST::Class::User> object.
 
 =head2 B<name>
+
 Returns the name of the project.
 
 =head2 B<category>
+
 Returns a hashref of the category of the project.
 
 =head2 B<self>
+
 Returns the JIRA REST API URL of the project.
 
 =head2 B<versions>
+
 Returns a list of the versions of the project.
 
 =head2 B<metadata>
